netapp_ontap.models.volume_space API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_space`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeSpaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `afs_total: Size GET POST PATCH`

    Total size of AFS, excluding snap-reserve, in bytes.

  `auto_adaptive_compression_footprint_data_reduction: Size GET`

    Savings achieved due to Auto Adaptive Compression, in bytes.

  `available: Size GET`

    The available space, in bytes.

  `available_percent: Size GET POST PATCH`

    The space available, as a percent.

  `block_storage_inactive_user_data: Size GET`

    The size that is physically used in the block storage of the volume and has a cold temperature. In bytes. This parameter is only supported if the volume is in an aggregate that is either attached to a cloud store or could be attached to a cloud store.

  `block_storage_inactive_user_data_percent: Size GET`

    Percentage of size that is physically used in the performance tier of the volume.

  `capacity_tier_footprint: Size GET`

    Space used by capacity tier for this volume in the FabricPool aggregate, in bytes.

  `capacity_tier_footprint_data_reduction: Size GET`

    Savings achieved in the space used by the capacity tier for this volume in the FabricPool aggregate, in bytes.

  `compaction_footprint_data_reduction: Size GET`

    Savings achieved due to Data Compaction, in bytes.

  `cross_volume_dedupe_metafiles_footprint: Size GET`

    Cross volume deduplication metadata footprint, in bytes.

  `cross_volume_dedupe_metafiles_temporary_footprint: Size GET`

    Cross volume temporary deduplication metadata footprint, in bytes.

  `dedupe_metafiles_footprint: Size GET`

    Deduplication metadata footprint, in bytes.

  `dedupe_metafiles_temporary_footprint: Size GET`

    Temporary deduplication metadata footprint, in bytes.

  `delayed_free_footprint: Size GET`

    Delayed free blocks footprint, in bytes.

  `effective_total_footprint: Size GET`

    Volume footprint after efficiency savings, in bytes. effective total footprint represents total footprint after deducting auto adaptive compression and compaction savings. effective-footprint includes aggregate metadata used by volume.

  `expected_available: Size GET POST PATCH`

    Size that should be available for the volume, irrespective of available size in the aggregate, in bytes.

  `file_operation_metadata: Size GET`

    File operation metadata footprint, in bytes.

  `filesystem_size: Size GET`

    Total usable size of the volume, in bytes.

  `filesystem_size_fixed: bool GET POST PATCH`

    Specifies whether the file system is to remain of the same size when set to true or to grow when set to false. This option is automatically set to true when a volume becomes SnapMirrored.

  `footprint: Size GET`

    Data used for this volume in the aggregate, in bytes.

  `fractional_reserve: Size GET POST PATCH`

    Used to change the amount of space reserved for overwrites of reserved objects in a volume.

  `full_threshold_percent: Size GET POST PATCH`

    Volume full threshold percentage at which EMS warnings can be sent.

  `is_used_stale: bool GET`

    Specifies if the virtual space used is stale.

  `large_size_enabled: bool GET POST PATCH`

    Indicates if the support for large FlexVol volumes and large files is enabled on this volume. When configured to true, FlexVol volume size can reach up to 300TB and single file size can reach 128TB.

  `local_tier_footprint: Size GET`

    Space used by the local tier for this volume in the aggregate, in bytes.

  `logical_space: VolumeSpaceLogicalSpace GET POST PATCH`

    The logical_space field of the volume_space.

  `max_size: str GET POST PATCH`

    Indicates the maximum size supported for the FlexVol volume or for each constituent of the FlexGroup volume.

    Valid choices:

    - 100T
    - 300T
    - 600T
  `metadata: Size GET`

    Space used by the volume metadata in the aggregate, in bytes.

  `nearly_full_threshold_percent: Size GET POST PATCH`

    Volume nearly full threshold percentage at which EMS warnings can be sent.

  `over_provisioned: Size GET`

    The amount of space not available for this volume in the aggregate, in bytes.

  `overwrite_reserve: Size GET`

    Reserved space for overwrites, in bytes.

  `overwrite_reserve_used: Size GET`

    Overwrite logical reserve space used, in bytes.

  `percent_used: Size GET`

    Percentage of the volume size that is used.

  `performance_tier_footprint: Size GET`

    Space used by the performance tier for this volume in the FabricPool aggregate, in bytes.

  `physical_used: Size GET POST PATCH`

    Size that is physically used in the volume, in bytes. Physical used is effective total footprint which is equivalent to total footprint after deducting auto adaptive compression and compaction savings. Physical-used also includes aggregate metadata used by volume.

  `physical_used_percent: Size GET POST PATCH`

    Size that is physically used in the volume, as a percentage.

  `size: Size GET POST PATCH`

    Total provisioned size. The default size is equal to the minimum size of 20MB, in bytes.

  `size_available_for_snapshots: Size GET`

    Available space for snapshots from snap-reserve, in bytes.

  `snapmirror_destination_footprint: Size GET`

    SnapMirror destination footprint, in bytes.

  `snapshot: VolumeSpaceSnapshot GET POST PATCH`

    The snapshot field of the volume_space.

  `snapshot_reserve_unusable: Size GET`

    Snapshot reserve that is not available for snapshot creation, in bytes.

  `snapshot_spill: Size GET`

    Space used by the snapshot copies beyond the snap-reserve, in bytes.

  `total_footprint: Size GET`

    Data and metadata used for this volume in the aggregate, in bytes.

  `total_metadata: Size GET`

    Space used by the total metadata in the volume, in bytes.

  `total_metadata_footprint: Size GET`

    Space used by the volume metadata footprint in the aggregate, in bytes.

  `used: Size GET`

    The virtual space used (includes volume reserves) before storage efficiency, in bytes.

  `used_by_afs: Size GET POST PATCH`

    The space used by Active Filesystem, in bytes.

  `user_data: Size GET`

    User data, in bytes.

  `volume_guarantee_footprint: Size GET`

    Space reserved for future writes in the volume, in bytes.